/**
 * lazy-hydration v0.1.5
 * (c) 2019 Rahul Kadyan <hi@znck.me> (https://znck.me)
 * @license MIT
 * @description Built with rollup-plugin-vue v4.6.1 and vue-template-compiler v2.5.22
 */
var isBrowser = typeof window !== "undefined";
var io = typeof IntersectionObserver !== "undefined" ? new IntersectionObserver(function (entries) {
  entries.forEach(function (entry) {
    if (entry.isIntersecting || entry.intersectionRatio > 0) {
      entry.target.parentElement.hydrate && entry.target.parentElement.hydrate();
    }
  });
}) : null;
var script = {
  props: {
    onClick: Boolean,
    onHover: Boolean,
    onInteraction: Boolean,
    whenVisible: Boolean,
    whenIdle: Boolean,
    ssrOnly: Boolean
  },
  data: function data() {
    return {
      hydrated: !isBrowser
    };
  },
  beforeCreate: function beforeCreate() {
    var _this = this;

    if (isBrowser) {
      var render = this.$options.render;

      this.$options.render = function () {
        for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
          args[_key] = arguments[_key];
        }

        var vnode = render.apply(_this, args);
        vnode.asyncFactory = _this.hydrated ? {
          resolved: true
        } : {};
        vnode.isAsyncPlaceholder = !_this.hydrated;
        return vnode;
      };
    }
  },
  mounted: function mounted() {
    var _this2 = this;

    if (this.$el.childElementCount === 0) {
      // No SSR rendered content.
      this.hydrated = true;
      return;
    }

    if (this.ssrOnly) return;

    if (this.whenIdle) {
      var id = requestIdleCallback(function () {
        requestAnimationFrame(function () {
          _this2.hydrate();
        });
      }, {
        timeout: 500
      });

      this.idle = function () {
        return cancelIdleCallback(id);
      };
    }

    if (this.whenVisible) {
      this.$el.hydrate = this.hydrate;
      if (io) io.observe(this.$el.children[0]);else console.warn("IntersectionObserver polyfill is required.");

      this.visible = function () {
        io && io.unobserve(_this2.$el);
        delete _this2.$el.hydrate;
      };
    }

    if (this.onClick) {
      this.$el.addEventListener("click", this.hydrate, {
        capture: true,
        once: true
      });

      this.click = function () {
        return _this2.$el.removeEventListener("click", _this2.hydrate);
      };
    }

    if (this.onHover || this.onInteraction) {
      this.$el.addEventListener("mouseenter", this.hydrate, {
        capture: true,
        once: true
      });

      this.hover = function () {
        return _this2.$el.removeEventListener("mouseenter", _this2.hydrate);
      };
    }

    if (this.onInteraction) {
      this.$el.addEventListener("focus", this.hydrate, {
        capture: true,
        once: true
      });

      this.interaction = function () {
        return _this2.$el.removeEventListener("focus", _this2.hydrate);
      };
    }
  },
  beforeDestroy: function beforeDestroy() {
    this.cleanup();
  },
  methods: {
    cleanup: function cleanup() {
      var handlers = ["visible", "idle", "click", "hover", "interaction"];

      for (var _i = 0; _i < handlers.length; _i++) {
        var handler = handlers[_i];

        if (handler in this) {
          this[handler]();
          delete this[handler];
        }
      }
    },
    hydrate: function hydrate() {
      this.hydrated = true;
      this.cleanup();
    }
  }
};

function normalizeComponent(compiledTemplate, injectStyle, defaultExport, scopeId, isFunctionalTemplate, moduleIdentifier
/* server only */
, isShadowMode, createInjector, createInjectorSSR, createInjectorShadow) {
  if (typeof isShadowMode === 'function') {
    createInjectorSSR = createInjector;
    createInjector = isShadowMode;
    isShadowMode = false;
  } // Vue.extend constructor export interop


  const options = typeof defaultExport === 'function' ? defaultExport.options : defaultExport; // render functions

  if (compiledTemplate && compiledTemplate.render) {
    options.render = compiledTemplate.render;
    options.staticRenderFns = compiledTemplate.staticRenderFns;
    options._compiled = true; // functional template

    if (isFunctionalTemplate) {
      options.functional = true;
    }
  } // scopedId


  if (scopeId) {
    options._scopeId = scopeId;
  }

  let hook;

  if (moduleIdentifier) {
    // server build
    hook = function (context) {
      // 2.3 injection
      context = context || // cached call
      this.$vnode && this.$vnode.ssrContext || // stateful
      this.parent && this.parent.$vnode && this.parent.$vnode.ssrContext; // functional
      // 2.2 with runInNewContext: true

      if (!context && typeof __VUE_SSR_CONTEXT__ !== 'undefined') {
        context = __VUE_SSR_CONTEXT__;
      } // inject component styles


      if (injectStyle) {
        injectStyle.call(this, createInjectorSSR(context));
      } // register component module identifier for async chunk inference


      if (context && context._registeredComponents) {
        context._registeredComponents.add(moduleIdentifier);
      }
    }; // used by ssr in case component is cached and beforeCreate
    // never gets called


    options._ssrRegister = hook;
  } else if (injectStyle) {
    hook = isShadowMode ? function () {
      injectStyle.call(this, createInjectorShadow(this.$root.$options.shadowRoot));
    } : function (context) {
      injectStyle.call(this, createInjector(context));
    };
  }

  if (hook) {
    if (options.functional) {
      // register for functional component in vue file
      const originalRender = options.render;

      options.render = function renderWithStyleInjection(h, context) {
        hook.call(context);
        return originalRender(h, context);
      };
    } else {
      // inject component registration as beforeCreate hook
      const existing = options.beforeCreate;
      options.beforeCreate = existing ? [].concat(existing, hook) : [hook];
    }
  }

  return defaultExport;
}

/* script */
const __vue_script__ = script;
// For security concerns, we use only base name in production mode. See https://github.com/vuejs/rollup-plugin-vue/issues/258
script.__file = "Hydrate.vue";

/* template */
var __vue_render__ = function () {var _vm=this;var _h=_vm.$createElement;var _c=_vm._self._c||_h;return (_vm.hydrated)?_c('div',{staticStyle:{"display":"contents"}},[_vm._t("default")],2):_c('div',{staticStyle:{"display":"contents"}})};
var __vue_staticRenderFns__ = [];

  /* style */
  const __vue_inject_styles__ = undefined;
  /* scoped */
  const __vue_scope_id__ = undefined;
  /* module identifier */
  const __vue_module_identifier__ = undefined;
  /* functional template */
  const __vue_is_functional_template__ = false;
  /* style inject */
  
  /* style inject SSR */
  

  
  var Hydrate = normalizeComponent(
    { render: __vue_render__, staticRenderFns: __vue_staticRenderFns__ },
    __vue_inject_styles__,
    __vue_script__,
    __vue_scope_id__,
    __vue_is_functional_template__,
    __vue_module_identifier__,
    undefined,
    undefined
  );

export default Hydrate;
